/*
    Flaticon icon font: Flaticon
    Creation date: 06/05/2019 12:06
    */
@font-face {
  font-family: "Flaticon";
  src: url("./Flaticon.eot");
  src: url("./Flaticon.eot?#iefix") format("embedded-opentype"), url("./Flaticon.woff2") format("woff2"), url("./Flaticon.woff") format("woff"), url("./Flaticon.ttf") format("truetype"), url("./Flaticon.svg#Flaticon") format("svg");
  font-weight: normal;
  font-style: normal; }

@media screen and (-webkit-min-device-pixel-ratio: 0) {
  @font-face {
    font-family: "Flaticon";
    src: url("./Flaticon.svg#Flaticon") format("svg"); } }

.fi:before {
  display: inline-block;
  font-family: "Flaticon";
  font-style: normal;
  font-weight: normal;
  font-variant: normal;
  line-height: 1;
  text-decoration: inherit;
  text-rendering: optimizeLegibility;
  text-transform: none;
  -moz-osx-font-smoothing: grayscale;
  -webkit-font-smoothing: antialiased;
  font-smoothing: antialiased; }

.flaticon-airplane:before {
  content: "\f100"; }

.flaticon-add:before {
  content: "\f101"; }

.flaticon-ferry:before {
  content: "\f102"; }

.flaticon-box:before {
  content: "\f103"; }

.flaticon-lorry:before {
  content: "\f104"; }

.flaticon-warehouse:before {
  content: "\f105"; }
